==> statistic-3.0.zip: statistic/global.php <==
<?php

session_start();
include_once('config.php');
include_once('database.php');
include_once('code.php');
include_once('types.php');
include_once('classes.php');
include_once('stat_functions.php');
$Database = new Database($Config['Database']['Host'], $Config['Database']['User'], $Config['Database']['Password'], $Config['Database']['Database']);
$Database->Prefix = $Config['Database']['Prefix'];
$Database->charset($Config['Database']['Charset']);

function ShowPage($Content)
{
  global $Config;
  $Output = '<?xml version="1.0" encoding="'.$Config['Web']['Charset'].'"?>'."\n". // <?  
'<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
  <meta http-equiv="Content-Language" content="cs"/>
  <meta http-equiv="Content-Type" content="text/html; charset='.$Config['Web']['Charset'].'"/>
  <title>'.$Config['Web']['Title'].'</title>
  <link rel="StyleSheet" href="style/style.css" type="text/css" media="all"/>
  </head><body>';
  $Output .= $Content.'</body></html>';
  echo($Output);
}


function MakeLink($Target, $Title)
{
  return('<a href="'.$Target.'">'.$Title.'</a>'); 
}

function Table($Table)
{
  $Result = '<table cellspacing="0" class="BasicTable">';
  $Result .= '<tr>';
  foreach($Table['Header'] as $Item)
    $Result .= '<th>'.$Item.'</th>';
  $Result .= '</tr>';
  foreach($Table['Rows'] as $Row)
  {
    $Result .= '<tr>';
    foreach($Row as $Item)
      $Result .= '<td>'.$Item.'</td>';
    $Result .= '</tr>';
  }
  $Result .= '</table>';
  return($Result);
}

function ShowEditTable($ClassName, $Values)
{
  global $Classes, $Types;
  $Class = $Classes[$ClassName];
  $Table = array(
    'Header' => array('Poloka', 'Hodnota'),
    'Rows' => array(),
  );
  
  foreach($Class as $Index => $Item)
  {
    if(!array_key_exists($Index, $Values)) $Values[$Index] = $Item['Default']; 
    switch($Item['Type'])
    {
      case 'Boolean':       
        if($Values[$Index] == 0) $Checked = ''; else $Checked = ' checked="yes"';
        $Edit = '<input type="checkbox" name="'.$Index.'"'.$Checked.'>';
        break;
      case 'String': 
        $Edit = '<input type="text" name="'.$Index.'" value="'.$Values[$Index].'">';
        break;
      case 'Integer': 
        $Edit = '<input type="text" name="'.$Index.'" value="'.$Values[$Index].'">';
        break;
      default:
        $Edit = 'Neznm typ';      
    }
    array_push($Table['Rows'], array($Item['Caption'], $Edit));
  }
  $Output = '<h3>Tabulka '.$ClassName.'</h3>'.Table($Table).MakeLink('?Operation=Add2', 'Pidat');
  return($Output); 
}

?>

==> statistic-3.1.zip: statistic/global.php <==
<?php

session_start();
include_once('config.php');
include_once('database.php');
include_once('code.php');
include_once('types.php');
include_once('classes.php');
include_once('stat_functions.php');
$Database = new Database($Config['Database']['Host'], $Config['Database']['User'], $Config['Database']['Password'], $Config['Database']['Database']);
$Database->Prefix = $Config['Database']['Prefix'];
$Database->charset($Config['Database']['Charset']);

// SQL injection hack protection
foreach($_POST as $Index => $Item) $_POST[$Index] = addslashes($Item);
foreach($_GET as $Index => $Item) $_GET[$Index] = addslashes($Item);

function ShowPage($Content)
{
  global $Config;
  $Output = '<?xml version="1.0" encoding="'.$Config['Web']['Charset'].'"?>'."\n". // <?  
'<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
  <meta http-equiv="Content-Language" content="cs"/>
  <meta http-equiv="Content-Type" content="text/html; charset='.$Config['Web']['Charset'].'"/>
  <title>'.$Config['Web']['Title'].'</title>
  <link rel="StyleSheet" href="style/style.css" type="text/css" media="all"/>
  </head><body>';
  $Output .= $Content.'</body></html>';
  echo($Output);
}


function MakeLink($Target, $Title)
{
  return('<a href="'.$Target.'">'.$Title.'</a>'); 
}

function Table($Table)
{
  $Result = '<table cellspacing="0" class="BasicTable">';
  $Result .= '<tr>';
  foreach($Table['Header'] as $Item)
    $Result .= '<th>'.$Item.'</th>';
  $Result .= '</tr>';
  foreach($Table['Rows'] as $Row)
  {
    $Result .= '<tr>';
    foreach($Row as $Item)
      $Result .= '<td>'.$Item.'</td>';
    $Result .= '</tr>';
  }
  $Result .= '</table>';
  return($Result);
}

function ShowEditTable($ClassName, $Values)
{
  global $Classes, $Types;
  $Class = $Classes[$ClassName];
  $Table = array(
    'Header' => array('Položka', 'Hodnota'),
    'Rows' => array(),
  );
  
  foreach($Class as $Index => $Item)
  {
    if(!array_key_exists($Index, $Values)) $Values[$Index] = $Item['Default']; 
    switch($Item['Type'])
    {
      case 'Boolean':       
        if($Values[$Index] == 0) $Checked = ''; else $Checked = ' checked="yes"';
        $Edit = '<input type="checkbox" name="'.$Index.'"'.$Checked.'>';
        break;
      case 'String': 
        $Edit = '<input type="text" name="'.$Index.'" value="'.$Values[$Index].'">';
        break;
      case 'Integer': 
        $Edit = '<input type="text" name="'.$Index.'" value="'.$Values[$Index].'">';
        break;
      default:
        $Edit = 'Neznámý typ';      
    }
    array_push($Table['Rows'], array($Item['Caption'], $Edit));
  }
  $Output = '<h3>Tabulka '.$ClassName.'</h3>'.Table($Table).MakeLink('?Operation=Add2', 'Přidat');
  return($Output); 
}

?>
